@@ -18,23 +18,22 @@ from netbox_storage.models import Partition, PhysicalVolume, VolumeGroup, Drive
 
 class PhysicalVolumeForm(NetBoxModelForm):
     """Form for creating a new PhysicalVolume object."""
-    drive = DynamicModelChoiceField(
+    drive_id = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         label="Drive",
-        widget=APISelect(
-            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:drive-list")}
-        ),
+        initial_params={
+            'partitions': '$partition'
+        },
         help_text="The Drive e.g. Hard Drive 1",
     )
     partition = DynamicModelChoiceField(
-        queryset=Partition.objects.all(),
+        queryset=Partition.objects.filter(
+    # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+        ),
         label="Partition",
         query_params={
-            'drive_id': '$drive'
+            'drive_id': '$drive_id'
         },
-        widget=APISelect(
-            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:partition-list")}
-        ),
         help_text="The Partition of the Drive e.g. /dev/sdc1",
     )
     pv_name = CharField(
@@ -60,7 +59,7 @@ class PhysicalVolumeForm(NetBoxModelForm):
         (
             "Storage Configuration",
             (
-                "drive",
+                "drive_id",
                 "partition",
             ),
         ),
