@@ -37,7 +37,6 @@ from netbox_storage.views import (
     PhysicalVolumeView,
     PhysicalVolumeDeleteView,
     DrivePartitionListView,
-    PartitionPhysicalVolumeListView,
     # VolumeGroup
     VolumeGroupListView,
     VolumeGroupEditView,
@@ -53,7 +52,7 @@ from netbox_storage.views import (
     LogicalVolumeBulkEditView,
     LogicalVolumeBulkDeleteView,
     LogicalVolumeView,
-    LogicalVolumeDeleteView, VolumeGroupPhysicalVolumeListView, DrivePhysicalVolumeListView,
+    LogicalVolumeDeleteView,
 )
 
 app_name = "netbox_storage"
@@ -77,7 +76,6 @@ urlpatterns = [
         kwargs={"model": Drive},
     ),
     path("drive/<int:pk>/partition/", DrivePartitionListView.as_view(), name="drive_partitions"),
-    path("drive/<int:pk>/physicalvolume/", DrivePhysicalVolumeListView.as_view(), name="drive_physicalvolumes"),
     #
     # Filesystem urls
     #
@@ -112,9 +110,6 @@ urlpatterns = [
         name="partition_changelog",
         kwargs={"model": Partition},
     ),
-    path("partition/<int:pk>/physicalvolume/",
-         PartitionPhysicalVolumeListView.as_view(),
-         name="partition_physicalvolumes"),
     #
     # PhysicalVolume urls
     #
@@ -149,9 +144,6 @@ urlpatterns = [
         name="volumegroup_changelog",
         kwargs={"model": VolumeGroup},
     ),
-    path("volumegroup/<int:pk>/physicalvolume/",
-         VolumeGroupPhysicalVolumeListView.as_view(),
-         name="volumegroup_physicalvolumes"),
     #
     # LogicalVolume urls
     #
